pub struct CharacterCollision {
pub entity: Entity,
pub character_translation: Vect,
pub character_rotation: Rot,
pub translation_applied: Vect,
pub translation_remaining: Vect,
pub hit: ShapeCastHit,
}Expand description
A collision between the character and its environment during its movement.
Fields
entity: EntityThe entity hit by the character.
character_translation: VectThe position of the character when the collider was hit.
character_rotation: RotThe rotation of the character when the collider was hit.
translation_applied: VectThe translation that was already applied to the character when the hit happens.
translation_remaining: VectThe translations that was still waiting to be applied to the character when the hit happens.
hit: ShapeCastHitGeometric information about the hit.